Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(325)

Unified Diff: third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp

Issue 2654083006: Revert of Sync requestFullscreen() and exitFullscreen() algorithms with the spec (Closed)
Patch Set: add failing test expectations Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
diff --git a/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp b/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
index ec573b5074669e8af726a4c74d915dc1d82b1178..29479f8ce9309bc445336da85dc05408c9601826 100644
--- a/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
+++ b/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
@@ -506,21 +506,24 @@ void WebRemoteFrameImpl::willEnterFullscreen() {
HTMLFrameOwnerElement* ownerElement =
toHTMLFrameOwnerElement(frame()->owner());
- // Call |requestFullscreen()| on |ownerElement| to make it the pending
- // fullscreen element in anticipation of the coming |didEnterFullscreen()|
- // call.
+ // Call requestFullscreen() on |ownerElement| to make it the provisional
+ // fullscreen element in FullscreenController, and to prepare
+ // fullscreenchange events that will need to fire on it and its (local)
+ // ancestors. The events will be triggered if/when fullscreen is entered.
//
// PrefixedForCrossProcessDescendant is necessary because:
// - The fullscreen element ready check and other checks should be bypassed.
// - |ownerElement| will need :-webkit-full-screen-ancestor style in addition
// to :-webkit-full-screen.
//
// TODO(alexmos): currently, this assumes prefixed requests, but in the
// future, this should plumb in information about which request type
// (prefixed or unprefixed) to use for firing fullscreen events.
- Fullscreen::requestFullscreen(
- *ownerElement,
- Fullscreen::RequestType::PrefixedForCrossProcessDescendant);
+ Fullscreen::requestFullscreen(*ownerElement,
+ Fullscreen::RequestType::Prefixed,
+ true /* forCrossProcessAncestor */);
}
void WebRemoteFrameImpl::setHasReceivedUserGesture() {
« no previous file with comments | « third_party/WebKit/Source/web/WebPluginContainerImpl.cpp ('k') | third_party/WebKit/Source/web/WebViewImpl.h » ('j') | no next file with comments »
@@ -506,21 +506,24 @@ void WebRemoteFrameImpl::willEnterFullscreen() {
//
- // PrefixedForCrossProcessDescendant is necessary because:
- // - The fullscreen element ready check and other checks should be bypassed.
- // - |ownerElement| will need :-webkit-full-screen-ancestor style in addition
- // to :-webkit-full-screen.
+ // Passing |forCrossProcessAncestor| to requestFullscreen is necessary
+ // because:
+ // - |ownerElement| will need :-webkit-full-screen-ancestor style in
+ // addition to :-webkit-full-screen.
+ // - there's no need to resend the ToggleFullscreen IPC to the browser
+ // process.
//
// TODO(alexmos): currently, this assumes prefixed requests, but in the

Powered by Google App Engine
This is Rietveld 408576698